![](https://github.com/freewili/freewili-python/raw/master/logo.jpg)
# FreeWili

[FreeWili](https://freewili.com) is a Python library for controlling and communicating with FreeWili boards.

## Installation

You can install freewili using pip by running the following command (Python 3.10+):
```
pip install freewili
```

Please visit https://freewili.github.io/freewili-python/index.html#installation for platform specific installation notes.

## Documentation

Documentation on how to use the API, development environment setup, and code examples can be found here:

https://freewili.github.io/freewili-python/

## License
FreeWili is licensed under the [MIT License](https://opensource.org/licenses/MIT).
